==> adios2-2.8.2_1.arm64_monterey.bottle.tar.gz: adios2/2.8.2_1/lib/cmake/adios2/adios2-fortran-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "adios2::fortran" for configuration "Release"
set_property(TARGET adios2::fortran APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(adios2::fortran PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "adios2::c;adios2::core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran.2.8.2.dylib"
  IMPORTED_SONAME_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran.2.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS adios2::fortran )
list(APPEND _IMPORT_CHECK_FILES_FOR_adios2::fortran "${_IMPORT_PREFIX}/lib/libadios2_fortran.2.8.2.dylib" )

# Import target "adios2::fortran_mpi" for configuration "Release"
set_property(TARGET adios2::fortran_mpi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(adios2::fortran_mpi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "adios2::c_mpi;adios2::core_mpi"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran_mpi.2.8.2.dylib"
  IMPORTED_SONAME_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran_mpi.2.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS adios2::fortran_mpi )
list(APPEND _IMPORT_CHECK_FILES_FOR_adios2::fortran_mpi "${_IMPORT_PREFIX}/lib/libadios2_fortran_mpi.2.8.2.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> adios2-2.8.3.arm64_monterey.bottle.tar.gz: adios2/2.8.3/lib/cmake/adios2/adios2-fortran-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "adios2::fortran" for configuration "Release"
set_property(TARGET adios2::fortran APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(adios2::fortran PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "adios2::c;adios2::core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran.2.8.3.dylib"
  IMPORTED_SONAME_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran.2.dylib"
  )

list(APPEND _cmake_import_check_targets adios2::fortran )
list(APPEND _cmake_import_check_files_for_adios2::fortran "${_IMPORT_PREFIX}/lib/libadios2_fortran.2.8.3.dylib" )

# Import target "adios2::fortran_mpi" for configuration "Release"
set_property(TARGET adios2::fortran_mpi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(adios2::fortran_mpi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "adios2::c_mpi;adios2::core_mpi"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran_mpi.2.8.3.dylib"
  IMPORTED_SONAME_RELEASE "${_IMPORT_PREFIX}/lib/libadios2_fortran_mpi.2.dylib"
  )

list(APPEND _cmake_import_check_targets adios2::fortran_mpi )
list(APPEND _cmake_import_check_files_for_adios2::fortran_mpi "${_IMPORT_PREFIX}/lib/libadios2_fortran_mpi.2.8.3.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
